# Chapter 7: Futures Market and Derivatives Strategies

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 7 章：期货市场与衍生品策略](../../zh/textbook/07_futures.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch07_futures.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch07_futures.py)
  - Extended example: [examples/04_mixed_assets.py](https://github.com/akfamily/akquant/blob/main/examples/04_mixed_assets.py)
  - Guide: [Strategy Guide](../guide/strategy.md)
